@@ -15,21 +15,21 @@
 """
 import unittest
 
-from zope.configuration._compat import u
-
-NS = u('ns')
-FOO = u('foo')
-XXX = u('xxx')
-SPLAT = u('splat')
-SPLATV = u('splatv')
-A = u('a')
-AVALUE = u('avalue')
-B = u('b')
-BVALUE = u('bvalue')
 
+NS = u'ns'
+FOO = u'foo'
+XXX = u'xxx'
+SPLAT = u'splat'
+SPLATV = u'splatv'
+A = u'a'
+AVALUE = u'avalue'
+B = u'b'
+BVALUE = u'bvalue'
 
+# pylint:disable=protected-access
 
 class ZopeXMLConfigurationErrorTests(unittest.TestCase):
+    maxDiff = None
 
     def _getTargetClass(self):
         from zope.configuration.xmlconfig import ZopeXMLConfigurationError
@@ -39,11 +39,16 @@ class ZopeXMLConfigurationErrorTests(unittest.TestCase):
         return self._getTargetClass()(*args, **kw)
 
     def test___str___uses_repr_of_info(self):
-        zxce = self._makeOne('info', Exception, 'value')
-        self.assertEqual(str(zxce), "'info'\n    Exception: value")
+        zxce = self._makeOne('info', Exception('value'))
+        self.assertEqual(
+            str(zxce),
+            "'info'\n    Exception: value"
+        )
+
 
 
 class ZopeSAXParseExceptionTests(unittest.TestCase):
+    maxDiff = None
 
     def _getTargetClass(self):
         from zope.configuration.xmlconfig import ZopeSAXParseException
@@ -53,23 +58,20 @@ class ZopeSAXParseExceptionTests(unittest.TestCase):
         return self._getTargetClass()(*args, **kw)
 
     def test___str___not_a_sax_error(self):
-        zxce = self._makeOne(Exception('Not a SAX error'))
-        self.assertEqual(str(zxce), "Not a SAX error")
+        zxce = self._makeOne("info", Exception('Not a SAX error'))
+        self.assertEqual(
+            str(zxce),
+            "info\n    Exception: Not a SAX error")
 
     def test___str___w_a_sax_error(self):
-        zxce = self._makeOne(Exception('filename.xml:24:32:WAAA'))
-        self.assertEqual(str(zxce), 'File "filename.xml", line 24.32, WAAA')
+        zxce = self._makeOne("info", Exception('filename.xml:24:32:WAAA'))
+        self.assertEqual(
+            str(zxce),
+            'info\n    Exception: filename.xml:24:32:WAAA')
 
 
 class ParserInfoTests(unittest.TestCase):
 
-    _tempdir = None
-
-    def tearDown(self):
-        if self._tempdir is not None:
-            import shutil
-            shutil.rmtree(self._tempdir)
-
     def _getTargetClass(self):
         from zope.configuration.xmlconfig import ParserInfo
         return ParserInfo
@@ -96,8 +98,8 @@ class ParserInfoTests(unittest.TestCase):
         pi = self._makeOne('/path/to/nonesuch.xml', 24, 32)
         pi.end(33, 21)
         self.assertEqual(str(pi),
-                        'File "/path/to/nonesuch.xml", line 24.32-33.21\n'
-                        '  Could not read source.')
+                         'File "/path/to/nonesuch.xml", line 24.32-33.21\n'
+                         '  Could not read source.')
 
     def test___str___w_good_file(self):
         pi = self._makeOne('tests//sample.zcml', 3, 2)
@@ -164,42 +166,62 @@ class ConfigurationHandlerTests(unittest.TestCase):
                                })
         self.assertEqual(handler.ignore_depth, 2)
 
+    def _check_elementNS_context_raises(self, raises, catches,
+                                        testing=False,
+                                        meth='endElementNS',
+                                        meth_args=((NS, FOO), FOO)):
+        class ErrorContext(FauxContext):
+            def end(self, *args):
+                raise raises("xxx")
+            begin = end
+        class Info(object):
+            _line = _col = None
+            def end(self, line, col):
+                self._line, self._col = line, col
+        context = ErrorContext()
+        info = Info()
+        context.setInfo(info)
+        locator = FauxLocator('tests//sample.zcml', 1, 1)
+        handler = self._makeOne(context, testing)
+        handler.setDocumentLocator(locator)
+        locator.line, locator.column = 7, 16
+        meth = getattr(handler, meth)
+        with self.assertRaises(catches) as exc:
+            meth(*meth_args)
+        return exc.exception, info
+
+    def _check_startElementNS_context_begin_raises(self, raises, catches, testing=False):
+        return self._check_elementNS_context_raises(
+            raises, catches, testing,
+            meth='startElementNS',
+            meth_args=((NS, FOO),
+                       FOO,
+                       {(XXX, SPLAT): SPLATV,
+                        (None, A): AVALUE,
+                        (None, B): BVALUE,
+                       })
+        )
+
     def test_startElementNS_context_begin_raises_wo_testing(self):
         from zope.configuration.xmlconfig import ZopeXMLConfigurationError
-        class ErrorContext(FauxContext):
-          def begin(self, *args):
-            raise AttributeError("xxx")
-        context = ErrorContext()
-        locator = FauxLocator('tests//sample.zcml', 1, 1)
-        handler = self._makeOne(context)
-        handler.setDocumentLocator(locator)
-        with self.assertRaises(ZopeXMLConfigurationError) as exc:
-            handler.startElementNS(
-                (NS, FOO),
-                FOO,
-                {(XXX, SPLAT): SPLATV,
-                 (None, A): AVALUE,
-                 (None, B): BVALUE,
-                })
-        self.assertEqual(exc.exception.info.file, 'tests//sample.zcml')
-        self.assertEqual(exc.exception.info.line, 1)
-        self.assertEqual(exc.exception.info.column, 1)
+        raised, _ = self._check_startElementNS_context_begin_raises(AttributeError,
+                                                                    ZopeXMLConfigurationError)
+        info = raised.info
+        self.assertEqual(info.file, 'tests//sample.zcml')
+        self.assertEqual(info.line, 7)
+        self.assertEqual(info.column, 16)
 
     def test_startElementNS_context_begin_raises_w_testing(self):
-        class ErrorContext(FauxContext):
-          def begin(self, *args):
-            raise AttributeError("xxx")
-        context = ErrorContext()
-        locator = FauxLocator('tests//sample.zcml', 1, 1)
-        handler = self._makeOne(context, True)
-        handler.setDocumentLocator(locator)
-        with self.assertRaises(AttributeError):
-            handler.startElementNS(
-                (NS, FOO), FOO,
-                {(XXX, SPLAT): SPLATV,
-                 (None, A): AVALUE,
-                 (None, B): BVALUE,
-                })
+        self._check_startElementNS_context_begin_raises(AttributeError,
+                                                        AttributeError,
+                                                        True)
+
+    def test_startElementNS_context_begin_raises_BaseException(self):
+        class Bex(BaseException):
+            pass
+        self._check_startElementNS_context_begin_raises(Bex,
+                                                        Bex)
+
 
     def test_startElementNS_normal(self):
         # Integration test of startElementNS / endElementNS pair.
@@ -230,47 +252,31 @@ class ConfigurationHandlerTests(unittest.TestCase):
         handler.endElementNS((NS, FOO), FOO)
         self.assertEqual(handler.ignore_depth, 0)
 
+    def _check_endElementNS_context_end_raises(self, raises, catches, testing=False):
+        return self._check_elementNS_context_raises(raises, catches, testing)
+
     def test_endElementNS_context_end_raises_wo_testing(self):
         from zope.configuration.xmlconfig import ZopeXMLConfigurationError
-        class ErrorContext(FauxContext):
-          def end(self):
-            raise AttributeError("xxx")
-        class Info(object):
-            _line = _col = None
-            def end(self, line, col):
-                self._line, self._col = line, col
-        context = ErrorContext()
-        info = Info()
-        context.setInfo(info)
-        locator = FauxLocator('tests//sample.zcml', 1, 1)
-        handler = self._makeOne(context)
-        handler.setDocumentLocator(locator)
-        locator.line, locator.column = 7, 16
-        with self.assertRaises(ZopeXMLConfigurationError) as exc:
-            handler.endElementNS((NS, FOO), FOO)
-        self.assertTrue(exc.exception.info is context.info)
-        self.assertEqual(exc.exception.info._line, 7)
-        self.assertEqual(exc.exception.info._col, 16)
+
+        raised, info = self._check_endElementNS_context_end_raises(AttributeError,
+                                                                   ZopeXMLConfigurationError)
+
+        self.assertIs(raised.info, info)
+        self.assertEqual(raised.info._line, 7)
+        self.assertEqual(raised.info._col, 16)
 
     def test_endElementNS_context_end_raises_w_testing(self):
-        class ErrorContext(FauxContext):
-          def end(self):
-            raise AttributeError("xxx")
-        class Info(object):
-            _line = _col = None
-            def end(self, line, col):
-                self._line, self._col = line, col
-        context = ErrorContext()
-        info = Info()
-        context.setInfo(info)
-        locator = FauxLocator('tests//sample.zcml', 1, 1)
-        handler = self._makeOne(context, True)
-        handler.setDocumentLocator(locator)
-        locator.line, locator.column = 7, 16
-        with self.assertRaises(AttributeError):
-            handler.endElementNS((NS, FOO), FOO)
-        self.assertEqual(context.info._line, 7)
-        self.assertEqual(context.info._col, 16)
+        _, info = self._check_endElementNS_context_end_raises(AttributeError,
+                                                              AttributeError,
+                                                              True)
+        self.assertEqual(info._line, 7)
+        self.assertEqual(info._col, 16)
+
+    def test_endElementNS_context_end_raises_BaseException(self):
+        class Bex(BaseException):
+            pass
+        self._check_endElementNS_context_end_raises(Bex,
+                                                    Bex)
 
     def test_evaluateCondition_w_have_no_args(self):
         context = FauxContext()
@@ -314,7 +320,7 @@ class ConfigurationHandlerTests(unittest.TestCase):
         context = FauxContext()
         handler = self._makeOne(context)
         with self.assertRaises(ValueError) as exc:
-                handler.evaluateCondition('installed')
+            handler.evaluateCondition('installed')
         self.assertEqual(str(exc.exception.args[0]),
                          "Package name missing: 'installed'")
 
@@ -346,7 +352,7 @@ class ConfigurationHandlerTests(unittest.TestCase):
         context = FauxContext()
         handler = self._makeOne(context)
         self.assertTrue(
-                handler.evaluateCondition('not-installed nonsuch.package'))
+            handler.evaluateCondition('not-installed nonsuch.package'))
 
     def test_evaluateCondition_w_unknown_verb(self):
         context = FauxContext()
@@ -380,36 +386,38 @@ class Test_processxmlfile(unittest.TestCase):
         return processxmlfile(*args, **kw)
 
     def test_w_empty_xml(self):
+        from io import StringIO
         from zope.configuration.config import ConfigurationMachine
         from zope.configuration.xmlconfig import registerCommonDirectives
         from zope.configuration.xmlconfig import ZopeSAXParseException
-        from zope.configuration._compat import StringIO
+
         context = ConfigurationMachine()
         registerCommonDirectives(context)
         with self.assertRaises(ZopeSAXParseException) as exc:
             self._callFUT(StringIO(), context)
-        self.assertEqual(str(exc.exception._v),
+        self.assertEqual(str(exc.exception.evalue),
                          '<string>:1:0: no element found')
 
     def test_w_valid_xml_fp(self):
         # Integration test, really
         from zope.configuration.config import ConfigurationMachine
         from zope.configuration.xmlconfig import registerCommonDirectives
-        from zope.configuration._compat import b
         from zope.configuration.tests.samplepackage import foo
-        file = open(path("samplepackage", "configure.zcml"))
+
         context = ConfigurationMachine()
         registerCommonDirectives(context)
-        self._callFUT(file, context)
+
+        with open(path("samplepackage", "configure.zcml")) as file:
+            self._callFUT(file, context)
         self.assertEqual(foo.data, [])
         context.execute_actions()
         data = foo.data.pop()
-        self.assertEqual(data.args, (('x', b('blah')), ('y', 0)))
+        self.assertEqual(data.args, (('x', (b'blah')), ('y', 0)))
         self.assertEqual(clean_info_path(repr(data.info)),
-                'File "tests/samplepackage/configure.zcml", line 12.2-12.29')
+                         'File "tests/samplepackage/configure.zcml", line 12.2-12.29')
         self.assertEqual(clean_info_path(str(data.info)),
-                'File "tests/samplepackage/configure.zcml", line 12.2-12.29\n'
-                + '    <test:foo x="blah" y="0" />')
+                         'File "tests/samplepackage/configure.zcml", line 12.2-12.29\n'
+                         + '    <test:foo x="blah" y="0" />')
         self.assertEqual(data.package, None)
         self.assertEqual(data.basepath, None)
 
@@ -487,7 +495,7 @@ class Test_include(unittest.TestCase):
         with _Monkey(xmlconfig, logger=logger):
             self._callFUT(context)
         self.assertEqual(len(logger.debugs), 1)
-        self.assertEqual(logger.debugs[0], ('include %s' % fqn, (), {}))
+        self.assertEqual(logger.debugs[0], ('include %s', (fqn,), {}))
         self.assertEqual(len(context.actions), 1)
         action = context.actions[0]
         self.assertEqual(action['callable'], foo.data.append)
@@ -511,7 +519,7 @@ class Test_include(unittest.TestCase):
         with _Monkey(xmlconfig, logger=logger):
             self._callFUT(context, 'simple.zcml')
         self.assertEqual(len(logger.debugs), 1)
-        self.assertEqual(logger.debugs[0], ('include %s' % fqn, (), {}))
+        self.assertEqual(logger.debugs[0], ('include %s', (fqn,), {}))
         self.assertEqual(len(context.actions), 3)
         action = context.actions[0]
         self.assertEqual(action['callable'], simple.file_registry.append)
@@ -536,7 +544,6 @@ class Test_include(unittest.TestCase):
         from zope.configuration import xmlconfig
         from zope.configuration.config import ConfigurationMachine
         from zope.configuration.xmlconfig import registerCommonDirectives
-        from zope.configuration._compat import b
         from zope.configuration.tests import samplepackage
         from zope.configuration.tests.samplepackage import foo
         context = ConfigurationMachine()
@@ -549,20 +556,20 @@ class Test_include(unittest.TestCase):
         with _Monkey(xmlconfig, logger=logger):
             self._callFUT(context, package=samplepackage, files='baz*.zcml')
         self.assertEqual(len(logger.debugs), 3)
-        self.assertEqual(logger.debugs[0], ('include %s' % fqn1, (), {}))
-        self.assertEqual(logger.debugs[1], ('include %s' % fqn2, (), {}))
-        self.assertEqual(logger.debugs[2], ('include %s' % fqn3, (), {}))
+        self.assertEqual(logger.debugs[0], ('include %s', (fqn1,), {}))
+        self.assertEqual(logger.debugs[1], ('include %s', (fqn2,), {}))
+        self.assertEqual(logger.debugs[2], ('include %s', (fqn3,), {}))
         self.assertEqual(len(context.actions), 2)
         action = context.actions[0]
         self.assertEqual(action['callable'], foo.data.append)
         self.assertEqual(action['includepath'], (fqn2,))
         self.assertIsInstance(action['args'][0], foo.stuff)
-        self.assertEqual(action['args'][0].args, (('x', b('foo')), ('y', 2)))
+        self.assertEqual(action['args'][0].args, (('x', (b'foo')), ('y', 2)))
         action = context.actions[1]
         self.assertEqual(action['callable'], foo.data.append)
         self.assertEqual(action['includepath'], (fqn3,))
         self.assertIsInstance(action['args'][0], foo.stuff)
-        self.assertEqual(action['args'][0].args, (('x', b('foo')), ('y', 3)))
+        self.assertEqual(action['args'][0].args, (('x', (b'foo')), ('y', 3)))
         self.assertEqual(context.stack, before_stack)
         self.assertEqual(len(context._seen_files), 3)
         self.assertIn(fqn1, context._seen_files)
@@ -656,7 +663,7 @@ class Test_includeOverrides(unittest.TestCase):
         # dummy action, path from "previous" include
         context.includepath = (fqp,)
         def _callable():
-            pass
+            raise AssertionError("should not be called")
         context.actions.append({'discriminator': None,
                                 'callable': _callable,
                                })
@@ -665,7 +672,7 @@ class Test_includeOverrides(unittest.TestCase):
         with _Monkey(xmlconfig, logger=logger):
             self._callFUT(context, 'simple.zcml')
         self.assertEqual(len(logger.debugs), 1)
-        self.assertEqual(logger.debugs[0], ('include %s' % fqn, (), {}))
+        self.assertEqual(logger.debugs[0], ('include %s', (fqn,), {}))
         self.assertEqual(len(context.actions), 4)
         action = context.actions[0]
         self.assertEqual(action['discriminator'], None)
@@ -698,24 +705,22 @@ class Test_file(unittest.TestCase):
 
     def test_wo_execute_wo_context_wo_package(self):
         from zope.configuration import xmlconfig
-        from zope.configuration._compat import b
         from zope.configuration.tests.samplepackage import foo
         file_name = path("samplepackage", "configure.zcml")
         logger = LoggerStub()
         with _Monkey(xmlconfig, logger=logger):
             context = self._callFUT(file_name, execute=False)
         self.assertEqual(len(logger.debugs), 1)
-        self.assertEqual(logger.debugs[0], ('include %s' % file_name, (), {}))
+        self.assertEqual(logger.debugs[0], ('include %s', (file_name,), {}))
         self.assertEqual(len(foo.data), 0)
         self.assertEqual(len(context.actions), 1)
         action = context.actions[0]
         self.assertEqual(action['discriminator'],
-                         (('x', b('blah')), ('y', 0)))
+                         (('x', (b'blah')), ('y', 0)))
         self.assertEqual(action['callable'], foo.data.append)
 
     def test_wo_execute_wo_context_w_package(self):
         from zope.configuration import xmlconfig
-        from zope.configuration._compat import b
         from zope.configuration.tests import samplepackage
         from zope.configuration.tests.samplepackage import foo
         file_name = path("samplepackage", "configure.zcml")
@@ -724,20 +729,19 @@ class Test_file(unittest.TestCase):
             context = self._callFUT('configure.zcml', package=samplepackage,
                                     execute=False)
         self.assertEqual(len(logger.debugs), 1)
-        self.assertEqual(logger.debugs[0], ('include %s' % file_name, (), {}))
+        self.assertEqual(logger.debugs[0], ('include %s', (file_name,), {}))
         self.assertEqual(len(foo.data), 0)
         self.assertTrue(context.package is samplepackage)
         self.assertEqual(len(context.actions), 1)
         action = context.actions[0]
         self.assertEqual(action['discriminator'],
-                         (('x', b('blah')), ('y', 0)))
+                         (('x', (b'blah')), ('y', 0)))
         self.assertEqual(action['callable'], foo.data.append)
 
     def test_wo_execute_w_context(self):
         from zope.configuration import xmlconfig
         from zope.configuration.config import ConfigurationMachine
         from zope.configuration.xmlconfig import registerCommonDirectives
-        from zope.configuration._compat import b
         from zope.configuration.tests import samplepackage
         from zope.configuration.tests.samplepackage import foo
         context = ConfigurationMachine()
@@ -750,27 +754,26 @@ class Test_file(unittest.TestCase):
                                 execute=False)
         self.assertTrue(ret is context)
         self.assertEqual(len(logger.debugs), 1)
-        self.assertEqual(logger.debugs[0], ('include %s' % file_name, (), {}))
+        self.assertEqual(logger.debugs[0], ('include %s', (file_name,), {}))
         self.assertEqual(len(foo.data), 0)
         self.assertEqual(len(context.actions), 1)
         action = context.actions[0]
         self.assertEqual(action['discriminator'],
-                         (('x', b('blah')), ('y', 0)))
+                         (('x', (b'blah')), ('y', 0)))
         self.assertEqual(action['callable'], foo.data.append)
 
     def test_w_execute(self):
         import os
         from zope.configuration import xmlconfig
-        from zope.configuration._compat import b
         from zope.configuration.tests.samplepackage import foo
         file_name = path("samplepackage", "configure.zcml")
         logger = LoggerStub()
         with _Monkey(xmlconfig, logger=logger):
-            context = self._callFUT(file_name)
+            self._callFUT(file_name)
         self.assertEqual(len(logger.debugs), 1)
-        self.assertEqual(logger.debugs[0], ('include %s' % file_name, (), {}))
+        self.assertEqual(logger.debugs[0], ('include %s', (file_name,), {}))
         data = foo.data.pop()
-        self.assertEqual(data.args, (('x', b('blah')), ('y', 0)))
+        self.assertEqual(data.args, (('x', (b'blah')), ('y', 0)))
         self.assertTrue(
             data.info.file.endswith(
                 os.path.normpath('tests/samplepackage/configure.zcml')))
@@ -780,7 +783,7 @@ class Test_file(unittest.TestCase):
         self.assertEqual(data.info.ecolumn, 29)
         self.assertEqual(data.package, None)
         self.assertTrue(data.basepath.endswith(
-                        os.path.normpath('tests/samplepackage')))
+            os.path.normpath('tests/samplepackage')))
 
 
 class Test_string(unittest.TestCase):
@@ -790,7 +793,6 @@ class Test_string(unittest.TestCase):
         return string(*args, **kw)
 
     def test_wo_execute_wo_context(self):
-        from zope.configuration._compat import b
         from zope.configuration.tests.samplepackage import foo
         file_name = path("samplepackage", "configure.zcml")
         with open(file_name) as f:
@@ -800,13 +802,12 @@ class Test_string(unittest.TestCase):
         self.assertEqual(len(context.actions), 1)
         action = context.actions[0]
         self.assertEqual(action['discriminator'],
-                         (('x', b('blah')), ('y', 0)))
+                         (('x', (b'blah')), ('y', 0)))
         self.assertEqual(action['callable'], foo.data.append)
 
     def test_wo_execute_w_context(self):
         from zope.configuration.config import ConfigurationMachine
         from zope.configuration.xmlconfig import registerCommonDirectives
-        from zope.configuration._compat import b
         from zope.configuration.tests.samplepackage import foo
         context = ConfigurationMachine()
         registerCommonDirectives(context)
@@ -819,18 +820,17 @@ class Test_string(unittest.TestCase):
         self.assertEqual(len(context.actions), 1)
         action = context.actions[0]
         self.assertEqual(action['discriminator'],
-                         (('x', b('blah')), ('y', 0)))
+                         (('x', (b'blah')), ('y', 0)))
         self.assertEqual(action['callable'], foo.data.append)
 
     def test_w_execute(self):
-        from zope.configuration._compat import b
         from zope.configuration.tests.samplepackage import foo
         file_name = path("samplepackage", "configure.zcml")
         with open(file_name) as f:
             xml = f.read()
-        context = self._callFUT(xml)
+        self._callFUT(xml)
         data = foo.data.pop()
-        self.assertEqual(data.args, (('x', b('blah')), ('y', 0)))
+        self.assertEqual(data.args, (('x', (b'blah')), ('y', 0)))
         self.assertTrue(data.info.file, '<string>')
         self.assertEqual(data.info.line, 12)
         self.assertEqual(data.info.column, 2)
@@ -864,7 +864,6 @@ class XMLConfigTests(unittest.TestCase):
     def test_ctor_w_global_context_missing(self):
         import os
         from zope.configuration import xmlconfig
-        from zope.configuration._compat import b
         from zope.configuration.tests.samplepackage import foo
         here = os.path.dirname(__file__)
         path = os.path.join(here, "samplepackage", "configure.zcml")
@@ -873,17 +872,16 @@ class XMLConfigTests(unittest.TestCase):
         with _Monkey(xmlconfig, logger=logger):
             xc = self._makeOne(path)
         self.assertEqual(len(logger.debugs), 1)
-        self.assertEqual(logger.debugs[0], ('include %s' % path, (), {}))
+        self.assertEqual(logger.debugs[0], ('include %s', (path,), {}))
         self.assertEqual(len(foo.data), 0) # no execut_actions
         self.assertEqual(len(xc.context.actions), 1)
         action = xc.context.actions[0]
         self.assertEqual(action['discriminator'],
-                         (('x', b('blah')), ('y', 0)))
+                         (('x', (b'blah')), ('y', 0)))
         self.assertEqual(action['callable'], foo.data.append)
 
     def test_ctor(self):
         from zope.configuration import xmlconfig
-        from zope.configuration._compat import b
         from zope.configuration.tests import samplepackage
         from zope.configuration.tests.samplepackage import foo
         fqn = _packageFile(samplepackage, 'configure.zcml')
@@ -891,17 +889,16 @@ class XMLConfigTests(unittest.TestCase):
         with _Monkey(xmlconfig, logger=logger):
             xc = self._makeOne(fqn)
         self.assertEqual(len(logger.debugs), 1)
-        self.assertEqual(logger.debugs[0], ('include %s' % fqn, (), {}))
+        self.assertEqual(logger.debugs[0], ('include %s', (fqn,), {}))
         self.assertEqual(len(foo.data), 0) # no execut_actions
         self.assertEqual(len(xc.context.actions), 1)
         action = xc.context.actions[0]
         self.assertEqual(action['discriminator'],
-                         (('x', b('blah')), ('y', 0)))
+                         (('x', (b'blah')), ('y', 0)))
         self.assertEqual(action['callable'], foo.data.append)
 
     def test_ctor_w_module(self):
         from zope.configuration import xmlconfig
-        from zope.configuration._compat import b
         from zope.configuration.tests.samplepackage import foo
         from zope.configuration.tests import samplepackage
         fqn = _packageFile(samplepackage, 'configure.zcml')
@@ -909,18 +906,17 @@ class XMLConfigTests(unittest.TestCase):
         with _Monkey(xmlconfig, logger=logger):
             xc = self._makeOne("configure.zcml", samplepackage)
         self.assertEqual(len(logger.debugs), 1)
-        self.assertEqual(logger.debugs[0], ('include %s' % fqn, (), {}))
+        self.assertEqual(logger.debugs[0], ('include %s', (fqn,), {}))
         self.assertEqual(len(foo.data), 0) # no execut_actions
         self.assertEqual(len(xc.context.actions), 1)
         action = xc.context.actions[0]
         self.assertEqual(action['discriminator'],
-                         (('x', b('blah')), ('y', 0)))
+                         (('x', (b'blah')), ('y', 0)))
         self.assertEqual(action['callable'], foo.data.append)
 
     def test___call__(self):
         import os
         from zope.configuration import xmlconfig
-        from zope.configuration._compat import b
         from zope.configuration.tests import samplepackage
         from zope.configuration.tests.samplepackage import foo
         fqn = _packageFile(samplepackage, 'configure.zcml')
@@ -928,12 +924,12 @@ class XMLConfigTests(unittest.TestCase):
         with _Monkey(xmlconfig, logger=logger):
             xc = self._makeOne(fqn)
         self.assertEqual(len(logger.debugs), 1)
-        self.assertEqual(logger.debugs[0], ('include %s' % fqn, (), {}))
+        self.assertEqual(logger.debugs[0], ('include %s', (fqn,), {}))
         self.assertEqual(len(foo.data), 0)
         xc() # call to process the actions
         self.assertEqual(len(foo.data), 1)
         data = foo.data.pop(0)
-        self.assertEqual(data.args, (('x', b('blah')), ('y', 0)))
+        self.assertEqual(data.args, (('x', (b'blah')), ('y', 0)))
         self.assertTrue(
             data.info.file.endswith(
                 os.path.normpath('tests/samplepackage/configure.zcml')))
@@ -965,24 +961,23 @@ class Test_xmlconfig(unittest.TestCase):
     def test_wo_testing_passed(self):
         import os
         from zope.configuration import xmlconfig
-        from zope.configuration._compat import b
         from zope.configuration.tests import samplepackage
         from zope.configuration.tests.samplepackage import foo
         def _assertTestingFalse(func):
             def _wrapper(*args, **kw):
-                assert(not kw['testing'])
+                assert not kw['testing']
                 return func(*args, **kw)
             return _wrapper
         fqn = _packageFile(samplepackage, 'configure.zcml')
         context = xmlconfig._getContext()
         context.execute_actions = _assertTestingFalse(context.execute_actions)
         with _Monkey(xmlconfig,
-                        processxmlfile=_assertTestingFalse(
-                                                xmlconfig.processxmlfile)):
+                     processxmlfile=_assertTestingFalse(
+                         xmlconfig.processxmlfile)):
             self._callFUT(open(fqn), False)
         self.assertEqual(len(foo.data), 1)
         data = foo.data.pop(0)
-        self.assertEqual(data.args, (('x', b('blah')), ('y', 0)))
+        self.assertEqual(data.args, (('x', (b'blah')), ('y', 0)))
         self.assertTrue(
             data.info.file.endswith(
                 os.path.normpath('tests/samplepackage/configure.zcml')))
@@ -994,24 +989,23 @@ class Test_xmlconfig(unittest.TestCase):
     def test_w_testing_passed(self):
         import os
         from zope.configuration import xmlconfig
-        from zope.configuration._compat import b
         from zope.configuration.tests import samplepackage
         from zope.configuration.tests.samplepackage import foo
         def _assertTestingTrue(func):
             def _wrapper(*args, **kw):
-                assert(kw['testing'])
+                assert kw['testing']
                 return func(*args, **kw)
             return _wrapper
         fqn = _packageFile(samplepackage, 'configure.zcml')
         context = xmlconfig._getContext()
         context.execute_actions = _assertTestingTrue(context.execute_actions)
         with _Monkey(xmlconfig,
-                        processxmlfile=_assertTestingTrue(
-                                                xmlconfig.processxmlfile)):
+                     processxmlfile=_assertTestingTrue(
+                         xmlconfig.processxmlfile)):
             self._callFUT(open(fqn), True)
         self.assertEqual(len(foo.data), 1)
         data = foo.data.pop(0)
-        self.assertEqual(data.args, (('x', b('blah')), ('y', 0)))
+        self.assertEqual(data.args, (('x', (b'blah')), ('y', 0)))
         self.assertTrue(
             data.info.file.endswith(
                 os.path.normpath('tests/samplepackage/configure.zcml')))
@@ -1042,24 +1036,23 @@ class Test_testxmlconfig(unittest.TestCase):
     def test_w_testing_passed(self):
         import os
         from zope.configuration import xmlconfig
-        from zope.configuration._compat import b
         from zope.configuration.tests import samplepackage
         from zope.configuration.tests.samplepackage import foo
         def _assertTestingTrue(func):
             def _wrapper(*args, **kw):
-                assert(kw['testing'])
+                assert kw['testing']
                 return func(*args, **kw)
             return _wrapper
         fqn = _packageFile(samplepackage, 'configure.zcml')
         context = xmlconfig._getContext()
         context.execute_actions = _assertTestingTrue(context.execute_actions)
         with _Monkey(xmlconfig,
-                        processxmlfile=_assertTestingTrue(
-                                                xmlconfig.processxmlfile)):
+                     processxmlfile=_assertTestingTrue(
+                         xmlconfig.processxmlfile)):
             self._callFUT(open(fqn))
         self.assertEqual(len(foo.data), 1)
         data = foo.data.pop(0)
-        self.assertEqual(data.args, (('x', b('blah')), ('y', 0)))
+        self.assertEqual(data.args, (('x', (b'blah')), ('y', 0)))
         self.assertTrue(
             data.info.file.endswith(
                 os.path.normpath('tests/samplepackage/configure.zcml')))
@@ -1119,23 +1112,24 @@ def clean_path(s):
 
 def clean_actions(actions):
     return [
-      {'discriminator': action['discriminator'],
-       'info': clean_info_path(repr(action['info'])),
-       'includepath': [clean_path(p) for p in action['includepath']],
-       }
-      for action in actions
-      ]
+        {
+            'discriminator': action['discriminator'],
+            'info': clean_info_path(repr(action['info'])),
+            'includepath': [clean_path(p) for p in action['includepath']],
+        }
+        for action in actions
+    ]
 
 def clean_text_w_paths(error):
     r = []
-    for line in unicode(error).split("\n"):
-      line = line.rstrip()
-      if not line:
-        continue
-      l = line.find('File "')
-      if l >= 0:
-        line = line[:l] + clean_info_path(line[l:])
-      r.append(line)
+    for line in str(error).split("\n"):
+        line = line.rstrip()
+        if not line:
+            continue
+        l = line.find('File "')
+        if l >= 0:
+            line = line[:l] + clean_info_path(line[l:])
+        r.append(line)
     return '\n'.join(r)
 
 
@@ -1158,48 +1152,24 @@ class _Monkey(object):
             setattr(self.module, k, v)
 
     def __exit__(self, *exc_info):
-        for k, v in self.replacements.items():
+        for k in self.replacements:
             if k in self.orig:
                 setattr(self.module, k, self.orig[k])
-            else: #pragma NO COVERSGE
+            else: # pragma: no cover
                 delattr(self.module, k)
 
 
 class LoggerStub(object):
 
+    debugs = errors = warnings = infos = ()
+
     def __init__(self):
-        self.errors = []
-        self.warnings = []
-        self.infos = []
-        self.debugs = []
+        def make_append(lst):
+            return lambda msg, *args, **kwargs: lst.append((msg, args, kwargs))
 
-    def error(self, msg, *args, **kwargs):
-        self.errors.append((msg, args, kwargs))
+        for name in 'error', 'warning', 'info', 'debug':
+            lst = []
+            setattr(self, name + 's', lst)
 
-    def warning(self, msg, *args, **kwargs):
-        self.warnings.append((msg, args, kwargs))
-
-    def info(self, msg, *args, **kwargs):
-        self.infos.append((msg, args, kwargs))
-
-    def debug(self, msg, *args, **kwargs):
-        self.debugs.append((msg, args, kwargs))
-
-
-def test_suite():
-    return unittest.TestSuite((
-        unittest.makeSuite(ZopeXMLConfigurationErrorTests),
-        unittest.makeSuite(ZopeSAXParseExceptionTests),
-        unittest.makeSuite(ParserInfoTests),
-        unittest.makeSuite(ConfigurationHandlerTests),
-        unittest.makeSuite(Test_processxmlfile),
-        unittest.makeSuite(Test_openInOrPlain),
-        unittest.makeSuite(Test_include),
-        unittest.makeSuite(Test_exclude),
-        unittest.makeSuite(Test_includeOverrides),
-        unittest.makeSuite(Test_file),
-        unittest.makeSuite(Test_string),
-        unittest.makeSuite(XMLConfigTests),
-        unittest.makeSuite(Test_xmlconfig),
-        unittest.makeSuite(Test_testxmlconfig),
-    ))
+            func = make_append(lst)
+            setattr(self, name, func)
